@@ -5,7 +5,7 @@
  Martin Schlather, schlather@math.uni-mannheim.de
 
 
- Copyright (C) 2015 Martin Schlather
+ Copyright (C) 2015 -- 2017 Martin Schlather
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -38,19 +38,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define NATSCALE_MLE 3 /* check fitvario when changing; best not to change !!! */
 
 
+#ifdef __cplusplus
 extern "C" {
-
-  void getCov(int *n, double *COV);
-  
-  void test();
-  
-  void niceFFTnumber(int *n);
-  
-  void RNGtest();
-  
-  void GetCurrentNrOfModels(int *init, int *nr);
+#endif 
+  void GetCurrentNrOfModels(int *nr);
   void GetModelNr(char **name, int *n); /* transforms string "covfct" 
-					   into covnr of CovList */
+					   into covnr of DefList */
   void GetModelName(int *nr, char **name, char **nick); /* transforms covnr into string */
   SEXP GetParameterNames(SEXP nr);
   SEXP GetSubNames(SEXP nr);
@@ -63,7 +56,7 @@ extern "C" {
   void GetNrParameters(int *covnr, int* kappas);
   void PrintModelList(int *local, int *operat, int *nick); // used in Roger's book
   //  void GetModelList(int* idx, int*internal); // used in generate.R
-  SEXP GetAllModelNames();
+  SEXP GetAllModelNames(SEXP Newnames);
   SEXP GetCoordSystem(SEXP keynr, SEXP oldsystem, SEXP newsystem);
  
   /* Natural Scaling -- in contrast to the RFparameters(PracticalRange)
@@ -79,21 +72,22 @@ extern "C" {
   //  void GetKeyInfo(int *keyNr, int *total, int *lengths, int *dim, 
   //		  int *timespacedim,int *grid,int *type,int *maxdim,int *vdim);
   
-  SEXP GetExtModelInfo(SEXP keynr, SEXP level, SEXP spconform, SEXP whichSub);
+  SEXP GetModelInfo(SEXP keynr, SEXP level, SEXP spconform, SEXP whichSub,
+		       SEXP origin);
   SEXP GetModel(SEXP keynr, SEXP modus, SEXP spconform, SEXP whichSub,
-		SEXP SolveRandom, SEXP do_notreturnparam);
+		SEXP SolveRandom, SEXP returnwhichparam, SEXP origin);
   
   /* 
      check with InitSimulateRF in case of any changes !!
      both InitSimulateRF and DoGauss
   */
 
-  // PROCESSESNAMES
-  SEXP Init(SEXP model_reg, SEXP model, SEXP x, SEXP NA_OK);
+  // PROCESSES_NAMES
+  SEXP Init(SEXP Model_reg, SEXP Model, SEXP x, SEXP NA_OK);
   
   SEXP EvaluateModel(SEXP X, SEXP Covnr);
   
-  SEXP GetProcessType(SEXP model_reg, SEXP model);
+  SEXP GetProcessType(SEXP Model_reg, SEXP Model);
   // storing : current value
   // printlevel : current value
   // naturalscaling : fixed value
@@ -130,22 +124,20 @@ extern "C" {
 
 
   // for isotropic spatial data
-  void empiricalvariogram(double *x, int *dim, int *lx,
-			  double *values, int *repet,
-			  int *grid, double *bin, int *nbin, int *charact, 
-			  double *res, double *sd, int *n);
+  SEXP empirical(SEXP X, SEXP Dim, SEXP Lx, SEXP Values, SEXP Repet, SEXP Grid, 
+		SEXP Bin, SEXP Nbin, SEXP Vdim, SEXP Method);
 
-  void empvarioXT(double *X, double *T, 
-		  int *lx, 
-		  double *values, int *repet, int *grid,
-		  double *bin, int *nbin, 
-		  double *phi,    // vector of a real and an integer
-		  double *theta,  // vector of a real and an integer
-		  int *dT,   // 
-		  double *sum,   // \sum (a-b)^2 / 2
-		  double *sq,   // \sum (a-b)^4 / 4
-		  int *n);
-  SEXP fftVario3D(SEXP coord,
+  SEXP empvarioXT(SEXP Xsexp, SEXP Tsexp, 
+		  SEXP Lx, 
+		  SEXP Values, SEXP Repet, SEXP Grid,
+		  SEXP Bin, SEXP Nbin, 
+		  SEXP Phi,    // vector of a real and an integer
+		  SEXP Theta,  // vector of a real and an integer
+		  SEXP DT,   // in grid units, smallest positive value, for  
+		  //            the temporal lag of the emp. variogram
+		  //            stepT * nstepT is the greatest time span
+		  SEXP Vdim, SEXP Method);
+   SEXP fftVario3D(SEXP coord,
 		  SEXP sumvals,
 		  SEXP nbvals,
 		  SEXP bin,
@@ -162,11 +154,11 @@ extern "C" {
   
   
   // fractal dimension, 
-  SEXP boxcounting(double *z, int *lx, int * repet, double *factor, int *eps);
+  SEXP boxcounting(SEXP Z, SEXP LX,  SEXP Repet, SEXP Factor, SEXP Eps);
   SEXP detrendedfluc(SEXP dat, SEXP lx, SEXP repet, SEXP boxes, SEXP ldfa);
   SEXP periodogram(SEXP dat, SEXP len, SEXP repet, SEXP fftm, 
 		   SEXP part, SEXP shift);
-  SEXP minmax(SEXP dat, SEXP dim, SEXP ldim, SEXP boxes, SEXP lb, SEXP count);
+  SEXP minmax(SEXP dat, SEXP dim, SEXP ldim, SEXP boxes, SEXP lb);
   
 
   //  void Cov(int *reg, double *result);
@@ -177,6 +169,7 @@ extern "C" {
   //		       SEXP lx, SEXP result, SEXP nonzeros);
 
   SEXP VariogramIntern(SEXP reg);
+  SEXP PseudovariogramIntern(SEXP reg);
   //  SEXP CovMatrixLoc(SEXP reg, SEXP x, SEXP dist, SEXP xdim, SEXP lx,
   //		    SEXP result, SEXP nonzeros);
   SEXP CovLoc(SEXP reg, SEXP x, SEXP y, SEXP xdim, SEXP lx, SEXP result);
@@ -189,30 +182,27 @@ extern "C" {
   //  SEXP CovMatrixSelected(SEXP reg, SEXP selected, SEXP nsel, SEXP result,
   //			 SEXP nonzeros);
 
-  SEXP Delete_y(SEXP reg);
-  void DeleteKey(int *reg);
-  
+  SEXP GetNAPositions(SEXP model_reg, SEXP Model, SEXP x, SEXP values,
+		       SEXP integerNA, SEXP Print, SEXP vdim);
 
-  SEXP GetNAPositions(SEXP model, SEXP tsdim, SEXP xdim, SEXP integerNA, 
-		      SEXP Print);
-  
-  SEXP SetAndGetModelInfo(SEXP model_reg, SEXP model, 
+  SEXP SetAndGetModelInfo(SEXP Model_reg, SEXP Model, 
 			  SEXP spatialdim, SEXP distances, 
 			  SEXP ygiven, // TRUE is the standard variant
 			  SEXP Time, SEXP xdim, SEXP shortlen,
 			  SEXP allowforintegerNA, SEXP excludetrend);
   
- SEXP SetAndGetModelLikeli(SEXP model_reg, SEXP model, SEXP x);
+  SEXP SetAndGetModelLikelihood(SEXP Model_reg, SEXP Model, SEXP x,
+				SEXP origin);
     
   void PutValuesAtNA(int *reg, double *values);
   void PutValuesAtNAnoInit(int *reg, double *values);
   
   void expliciteDollarMLE(int * modelnr, double *values);
 
-  SEXP Take2ndAtNaOf1st(SEXP model_reg, SEXP model, SEXP model_bound,
+  SEXP Take2ndAtNaOf1st(SEXP Model_reg, SEXP Model, SEXP Model_bound,
 			SEXP spatialdim, SEXP Time, SEXP xdim, 
 			SEXP nbounds, SEXP skipchecks);
-  void UserGetNatScaling(double *natscale);
+  //  void UserGetNatScaling(double *natscale);
   
   void  GOUE(double * aniso, int *dim, double *grid_ext);
   
@@ -232,24 +222,15 @@ extern "C" {
 
 
   void GetMaxDims(int *maxints);
-
-  void MLEanymixed(int *anymixed);
   void GetModelRegister(char **name, int* nr);
   
   void MultiDimRange(int *model_nr, int *set, double *natscale);
   SEXP countelements(SEXP idx, SEXP N, SEXP Totparts);
   SEXP countneighbours(SEXP Xdim, SEXP parts, SEXP Squarelength, 
-		       SEXP cumgridlen, SEXP boxes);
+		       SEXP cumgridlen, SEXP boxes, SEXP MAXN);
   SEXP getelements(SEXP Idx, SEXP Xdim, SEXP N, SEXP Cumgridlen, SEXP Boxes);
   SEXP getneighbours(SEXP Xdim, SEXP Parts, SEXP Squarelength, SEXP Cumgridlen,
 		     SEXP Neighbours);
-  void duenen(int *Z, int *LL, int *BB, int *HH,
-	      int *states, int *change, double *lambda, int *l_lambda,
-	      int *maxtime, int *continuing, int *periodic);
-  
-  void Xduenen(int *ZZ, double *lambdas, double *lambdaw, double *lambdawm,
-	       double *lambdawp, double *lambdad, double *lambdag, 
-	       double *a, double *maxtime);
   
   
   void GetLH(int *LL, int *BB, int *HH);
@@ -261,34 +242,34 @@ extern "C" {
   void isAuthor(int *is);
   SEXP allintparam();
  
-  void sleepMicro(int *micro);
-  void sleepMilli(int *milli);
-  void hostname(char **h, int *i);
-  void pid(int *i);
-  SEXP getChar();
-
-  void start_debug();
+   void start_debug();
   void end_debug();
 
   SEXP set_boxcox(SEXP boxcox);
   SEXP get_boxcox();
   SEXP BoxCox_inverse(SEXP boxcox, SEXP res);
-  SEXP BoxCox_trafo(SEXP boxcox, SEXP res);	
+  SEXP BoxCox_trafo(SEXP boxcox, SEXP res, SEXP vdim, SEXP inverse);	
 
 
   SEXP get_logli_residuals(SEXP Reg);
-  SEXP get_likeliinfo(SEXP model_reg);
-  SEXP simple_residuals(SEXP model_reg);
+  SEXP get_logli_wholetrend(SEXP Reg);
+   SEXP get_likeliinfo(SEXP Model_reg);
+  SEXP simple_residuals(SEXP Model_reg);
   void PutGlblVar(int *reg, double *var);
 
-  SEXP get_linearpart(SEXP model_reg, SEXP Set);
+  SEXP get_linearpart(SEXP Model_reg, SEXP Set);
 
-  void attachRFoptions();
-  void detachRFoptions();
-  void RelaxUnknownRFoption(int *);
+  void attachRFoptionsRandomFields(int *show);
+  void detachRFoptionsRandomFields();
+  void RelaxUnknownRFoptions(int *relax);
+
+  SEXP maintainers_machine();
 
 
+#ifdef __cplusplus
 }
+#endif
+
 
 #endif /* RF_simu_PUBLIC_H*/
 
