@@ -123,9 +123,11 @@
  * factor any positive int n, up to 2^31 - 1.
  */
 
-/* here: nfac[26], hence n <= 10^12 ?*/
+/* 
+13 Aug 2018: changes by Schlather: all "static" declarations replaced
+*/
 
-static void fftmx(double *a, double *b, int ntot, int n, int nspan, int isn,
+void fftmx(double *a, double *b, int ntot, int n, int nspan, int isn,
 		  int m, int kt, double *at, double *ck, double *bt, double *sk,
 		  int *np, int *nfac)
 {
@@ -147,7 +149,7 @@ static void fftmx(double *a, double *b, int ntot, int n, int nspan, int isn,
 
     a--; b--; at--; ck--; bt--; sk--;
     np--;
-    nfac--;/* the global one!*/
+    nfac--;/*the global one!*/
 
     inc = abs(isn);
     nt = inc*ntot;
@@ -727,14 +729,16 @@ L570:
     if( nt >= 0) goto L_ord;
 } /* fftmx */
 
-static int old_n = 0;
 
-#define FFTMAXFACTORS 26
-static int nfac[FFTMAXFACTORS];
+/*
+static int old_n = 0;
+static int NFAC[21];
+static int *nfac = NFAC + 1;
 static int m_fac;
 static int kt;
 static int maxf;
 static int maxp;
+*/
 
 /* At the end of factorization,	 
  *	nfac[]	contains the factors,
@@ -742,7 +746,7 @@ static int maxp;
  *	kt	contains the number of square factors  */
 
 /* non-API, but used by package RandomFields */
-void fft_factor_(int n, int *pmaxf, int *pmaxp)
+int fft_factor(int n, int *pmaxf, int *pmaxp, int *pkt, int *pm_fac, int *NFAC)
 {
 /* fft_factor - factorization check and determination of memory
  *		requirements for the fft.
@@ -755,23 +759,27 @@ void fft_factor_(int n, int *pmaxf, int *pmaxp)
  *  If *pmaxp == 0  There was an illegal zero parameter among nseg, n, and nspn.
  *  If *pmaxp == 1  There we more than 15 factors to ntot.  */
 
-    int j, jj, k, sqrtk, kchanged;
+  /* schlather: returns 1=true on error else 0*/
+
+  int j, jj, k, sqrtk, kchanged,
+    m_fac, kt, maxf, maxp=0,
+    *nfac = NFAC + 1;
 
 	/* check series length */
 
     if (n <= 0) {
-	old_n = 0; *pmaxf = 0; *pmaxp = 0;
-	return;
-    }
-    else old_n = n;
+      // *pmaxf = 0; *pmaxp = 0;
+      return 1;
+    } //    else old_n = n;
 
 	/* determine the factors of n */
 
     m_fac = 0;
     k = n;/* k := remaining unfactored factor of n */
-    if (k == 1)
-	return;
-
+    if (k == 1) {
+      *pm_fac = m_fac;
+      return 0;
+    }
 	/* extract square factors first ------------------ */
 
     /* extract 4^2 = 16 separately
@@ -795,7 +803,6 @@ void fft_factor_(int n, int *pmaxf, int *pmaxp)
 	    kchanged = 0;
 	    sqrtk = (int)sqrt(k);
 	}
-	
     }
 
     if(k <= 4) {
@@ -828,9 +835,9 @@ void fft_factor_(int n, int *pmaxf, int *pmaxp)
 
     if (m_fac <= kt+1)
 	maxp = m_fac+kt+1;
-    if (m_fac+kt > FFTMAXFACTORS) {		/* error - too many factors */
-	old_n = 0; *pmaxf = 0; *pmaxp = 0;
-	return;
+    if (m_fac+kt > 20) {		/* error - too many factors */
+      // *pmaxf = 0; *pmaxp = 0;
+      return 1;
     }
     else {
 	if (kt != 0) {
@@ -846,21 +853,27 @@ void fft_factor_(int n, int *pmaxf, int *pmaxp)
     }
     *pmaxf = maxf;
     *pmaxp = maxp;
+    *pkt = kt;
+    *pm_fac = m_fac;
+    return 0;
 }
-
 
-Rboolean fft_work_(double *a, double *b, int nseg, int n, int nspn, int isn,
-		  double *work, int *iwork)
+//extern "C"  
+Rboolean fft_work(double *a, double *b, int nseg, int n, int nspn,
+		  int isn, double *work, int *iwork,
+		  int maxf, int kt, int m_fac, int *NFAC)
 {
-    int nf, nspan, ntot;
+  int nf, nspan, ntot,
+    *nfac = NFAC + 1;
 
 	/* check that factorization was successful */
 
-    if(old_n == 0) return FALSE;
+  // if(old_n == 0) return FALSE;
 
 	/* check that the parameters match those of the factorization call */
 
-    if(n != old_n || nseg <= 0 || nspn <= 0 || isn == 0)
+  if( // n != old_n ||
+       nseg <= 0 || nspn <= 0 || isn == 0)
 	return FALSE;
 
 	/* perform the transform */
@@ -872,6 +885,6 @@ Rboolean fft_work_(double *a, double *b, int nseg, int n, int nspn, int isn,
     fftmx(a, b, ntot, nf, nspan, isn, m_fac, kt,
 	  &work[0], &work[maxf], &work[2*(size_t)maxf], &work[3*(size_t)maxf],
 	  iwork, nfac);
-
+ 
     return TRUE;
 }
